import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alt", "bgStyles", "decoding", "errorIcon", "errorText", "fetchpriority", "loading", "onError", "onLoad", "placeholder", "skeleton", "sources", "spinner"];
import { cloneElement, useCallback, useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import ErrorImage from './ErrorImage.js';
import { BASE_CLASS, BASE_CLASS_FIGURE, CLASS_ERROR, CLASS_IMAGE, CLASS_PLACEHOLDER, CLASS_SKELETON, CLASS_SPINNER, DECODING, FETCHPRIORITY, LOADING } from './settings.js';
import { htmlImgProps } from './types.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var AtomImage = function AtomImage(_ref) {
  var alt = _ref.alt,
      bgStyles = _ref.bgStyles,
      _ref$decoding = _ref.decoding,
      decoding = _ref$decoding === void 0 ? DECODING.AUTO : _ref$decoding,
      errorIcon = _ref.errorIcon,
      errorText = _ref.errorText,
      _ref$fetchpriority = _ref.fetchpriority,
      fetchpriority = _ref$fetchpriority === void 0 ? FETCHPRIORITY.AUTO : _ref$fetchpriority,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? LOADING.EAGER : _ref$loading,
      _ref$onError = _ref.onError,
      onError = _ref$onError === void 0 ? function () {} : _ref$onError,
      _ref$onLoad = _ref.onLoad,
      onLoad = _ref$onLoad === void 0 ? function () {} : _ref$onLoad,
      placeholder = _ref.placeholder,
      skeleton = _ref.skeleton,
      _ref$sources = _ref.sources,
      sources = _ref$sources === void 0 ? [] : _ref$sources,
      Spinner = _ref.spinner,
      imgProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var imageRef = useRef();

  var _useState = useState(true),
      isLoading = _useState[0],
      setIsLoading = _useState[1];

  var _useState2 = useState(false),
      error = _useState2[0],
      setError = _useState2[1];

  var src = imgProps.src;
  useEffect(function () {
    setIsLoading(true);
    setError(false);
  }, [src, setIsLoading, setError]);
  var handleLoad = useCallback(function () {
    var _imageRef$current;

    var loadCompleted = imageRef == null ? void 0 : (_imageRef$current = imageRef.current) == null ? void 0 : _imageRef$current.complete;

    if (loadCompleted === true) {
      setIsLoading(!loadCompleted);
      onLoad && onLoad();
    }
  }, [onLoad, setIsLoading]);
  useEffect(function () {
    handleLoad();
  }, [handleLoad, imageRef]);
  var classNames = cx(BASE_CLASS, "is-" + (isLoading ? 'loading' : 'loaded'), error && "is-error");
  var classNamesFigure = cx(BASE_CLASS_FIGURE, placeholder && CLASS_PLACEHOLDER, skeleton && CLASS_SKELETON);

  var handleError = function handleError() {
    setIsLoading(false);
    setError(true);
    onError && onError();
  };

  var figureStyles = {
    backgroundImage: "url(" + (placeholder || skeleton) + ")"
  };
  var SpinnerExtended = Spinner && /*#__PURE__*/cloneElement(Spinner, {
    className: CLASS_SPINNER
  });
  return /*#__PURE__*/_jsxs("div", {
    className: classNames,
    children: [/*#__PURE__*/_jsx("figure", {
      className: classNamesFigure,
      style: !error && (placeholder || skeleton) ? figureStyles : {},
      children: /*#__PURE__*/_jsxs("picture", {
        children: [sources.map(function (source, idx) {
          return /*#__PURE__*/_jsx("source", _extends({}, source), idx);
        }), /*#__PURE__*/_jsx("img", _extends({
          alt: alt,
          className: CLASS_IMAGE,
          decoding: decoding,
          fetchpriority: fetchpriority,
          loading: loading,
          onError: handleError,
          onLoad: handleLoad,
          ref: imageRef
        }, imgProps))]
      })
    }), !error && isLoading && SpinnerExtended, error && /*#__PURE__*/_jsx(ErrorImage, {
      className: CLASS_ERROR,
      icon: errorIcon,
      text: errorText
    })]
  });
};

AtomImage.displayName = 'AtomImage';
export default AtomImage;
export { DECODING, FETCHPRIORITY, LOADING };